## Project Description

This is a test package used to test the publishing features of esrp release system.

## Requirements

* Python (3.6 or higher)
* azure-storage-blob

## Installation
Install using pip

`pip install esrp-release-test`
